
.. _toc-tool-btd:

.. module:: sisl_toolbox.btd


Block-tri-diagonal inversion algorithms
=======================================

Enables block-tri-diagonal inversion algorithms directly in Python.


.. autosummary::
   :toctree: generated/

   PivotSelfEnergy
   DownfoldSelfEnergy
   DeviceGreen
